@@ -142,7 +142,7 @@ class Session
   *
   * @param string $sid A session identifier.
   */
-  function Session( $sid="" )
+  function __construct( $sid="" )
   {
     global $sid, $sysname;
 
@@ -367,7 +367,7 @@ class Session
             //  Create a cookie for the sesssion
             setcookie('sid',$sid, 0,'/');
             // Recognise that we have started a session now too...
-            $this->Session($sid);
+            $this->__construct($sid);
             dbg_error_log( "Login", " Login: New session $session_id started for $username ($user_no)" );
             if ( isset($_POST['remember']) && intval($_POST['remember']) > 0 ) {
               $cookie = md5( $user_no ) . ";";
@@ -456,7 +456,7 @@ class Session
           $seq = $qry->Fetch();
           $session_id = $seq->nextval;
           $session_key = md5( rand(1010101,1999999999) . microtime() );  // just some random shite
-          dbg_error_log( "Login", " LSIDLogin: Valid username/password for $username ($usr->user_no)" );
+          dbg_error_log( "Login", " LSIDLogin: Valid username/password for $usr->username ($usr->user_no)" );
 
           // And create a session
           $sql = "INSERT INTO session (session_id, user_no, session_key) VALUES( ?, ?, ? )";
@@ -468,8 +468,8 @@ class Session
             //  Create a cookie for the sesssion
             setcookie('sid',$sid, 0,'/');
             // Recognise that we have started a session now too...
-            $this->Session($sid);
-            dbg_error_log( "Login", " LSIDLogin: New session $session_id started for $this->username ($usr->user_no)" );
+            $this->__construct($sid);
+            dbg_error_log( "Login", " LSIDLogin: New session $session_id started for $usr->username ($usr->user_no)" );
 
             $this->just_logged_in = true;
 
